[![Latest version](https://img.shields.io/static/v1?label=version&message=1.5.1&color=yellowgreen)](https://github.com/jakob-bagterp/colorist-for-python/releases/latest)
![Python 2.7 | 3.10 | 3.11 or higher](https://img.shields.io/static/v1?label=python&message=2.7%20|%203.10%20|%203.11%2B&color=blueviolet)
[![BSD-3-Clause license](https://img.shields.io/static/v1?label=license&message=BSD-3-Clause&color=blue)](https://github.com/jakob-bagterp/colorist-for-python/blob/master/LICENSE.md)
[![Codecov](https://codecov.io/gh/jakob-bagterp/browserist/branch/master/graph/badge.svg?token=1E69VOP4ED)](https://codecov.io/gh/jakob-bagterp/colorist-for-python)
[![Test](https://github.com/jakob-bagterp/colorist-for-python/actions/workflows/test.yml/badge.svg)](https://github.com/jakob-bagterp/colorist-for-python/actions/workflows/test.yml)

# 🌈 How to Install Colorist for Python 🌈
## Prerequisites
* Python version:
    * 2.7
    * 3.10, 3.11 or higher
* Terminal that supports color (i.e. [ANSI escape codes](https://en.wikipedia.org/wiki/ANSI_escape_code))

## Installation
### PyPI
Assuming that Python is installed already, execute this command in the terminal:

```shell
pip install colorist
```

If you already have installed Colorist for Python, use this command to upgrade to latest version:

```shell
pip install --upgrade colorist
```

### Homebrew
If you already have installed the [Homebrew](https://brew.sh) package manager for Mac and Linux, execute this terminal command to tap Colorist for Python:

```shell
brew tap jakob-bagterp/colorist
```

And then install:

```shell
brew install colorist
```

## Getting Started
Ready to go? [Learn how to use Colorist](https://github.com/jakob-bagterp/colorist-for-python/blob/master/README.md).
